@@ -2,7 +2,7 @@
 #define CONFIG_H
 
 /*
- * $Id: config.h,v 1.80 1997/12/17 02:30:46 jik Exp $
+ * $Id: config.h,v 1.81 1998/03/23 01:13:06 jik Exp $
  */
 
 /*
@@ -444,6 +444,15 @@
 #ifndef SENDMAIL
 #define SENDMAIL       "/usr/lib/sendmail -oi -t"
 #endif
+/* The command to use to verify that an E-mail address is valid.  it
+   should exit with status 0 if the address is valid.  It shouldn't
+   have any characters in it that are "special" to the shell.
+
+   If you don't want XRN to ever attempt to verify sender addresses in
+   postings and messages, don't define this. */
+#ifndef SENDMAIL_VERIFY
+#define SENDMAIL_VERIFY "/usr/lib/sendmail -bv >/dev/null"
+#endif
 
 #define SAVEMODE       "normal,headers,onedir"
 #define SAVE_DIR_DEFAULT	ONEDIR_SAVE
