@@ -1,5 +1,5 @@
 #if !defined(lint) && !defined(SABER) && !defined(GCC_WALL)
-static char XRNrcsid[] = "$Id: resources.c,v 1.60 1997/12/17 03:04:19 jik Exp $";
+static char XRNrcsid[] = "$Id: resources.c,v 1.62 1998/03/23 03:16:54 jik Exp $";
 #endif
 
 /*
@@ -108,6 +108,8 @@ static char XRNrcsid[] = "$Id: resources.c,v 1.60 1997/12/17 03:04:19 jik Exp $"
 #define XtNcomplainAboutBadDates "complainAboutBadDates"
 #define XtNconfirm              "confirm"
 #define XtCConfirm              "Confirm"
+#define XtNcourtesyCopyMessage	"courtesyCopyMessage"
+#define XtCCourtesyCopyMessage	"CourtesyCopyMessage"
 #define XtNdeadLetters          "deadLetters"
 #define XtCDeadLetters          "DeadLetters"
 #define XtNdefaultLines         "defaultLines"
@@ -243,6 +245,8 @@ static char XRNrcsid[] = "$Id: resources.c,v 1.60 1997/12/17 03:04:19 jik Exp $"
 #define XtCValidNewsgroups      "ValidNewsgroups"
 #define XtNverboseKill          "verboseKill"
 #define XtCVerboseKill          "VerboseKill"
+#define XtNverifyFrom		"verifyFrom"
+#define XtCVerifyFrom		"VerifyFrom"
 #define XtNversion              "version"
 #define XtCVersion              "Version"
 #define XtNwatchUnread          "watchUnread"
@@ -394,6 +398,8 @@ static XtResource resources[] = {
      XtOffset(app_res,dumpCore), XtRBoolean, (XtPointer) &defaultFalse},
     {XtNconfirm, XtCConfirm, XtRString, sizeof(char *),
      XtOffset(app_res,confirm), XtRString, (XtPointer) NULL},
+    {XtNcourtesyCopyMessage, XtCCourtesyCopyMessage, XtRString, sizeof(char *),
+     XtOffset(app_res,courtesyCopyMessage), XtRString, (XtPointer) NULL},
     {XtNdeadLetters, XtCDeadLetters, XtRString, sizeof(char *),
      XtOffset(app_res,deadLetters), XtRString, (XtPointer) DEADLETTER},
     {XtNdefaultLines, XtCDefaultLines, XtRInt, sizeof(int),
@@ -550,6 +556,8 @@ static XtResource resources[] = {
      XtOffset(app_res,validNewsgroups), XtRString, (XtPointer) NULL},
     {XtNverboseKill, XtCVerboseKill, XtRString, sizeof(String),
      XtOffset(app_res,verboseKill), XtRString, (XtPointer) "jms"},
+    {XtNverifyFrom, XtCVerifyFrom, XtRBoolean, sizeof(Boolean),
+     XtOffset(app_res,verifyFrom), XtRBoolean, (XtPointer) &defaultTrue},
     {XtNversion, XtCVersion, XtRString, sizeof(char *),
      XtOffset(app_res,version), XtRString, (XtPointer) NULL},
     {XtNwatchUnread, XtCWatchUnread, XtRString, sizeof(char *),
